ByteToChar

Struct ByteToChar 

pub struct ByteToChar<'a> { /* private fields */ }
Struct to map byte positions in a UTF-8 string to character positions, for error reporting.

Memory usage is optimized by storing cumulative character counts at 128 byte intervals, which allows for efficient mapping of byte positions to character positions without needing to store a mapping for every single byte.

Implementations

Source

impl<'a> ByteToChar<'a>

pub fn new(bytes: &'a [u8]) -> Self

Create a new ByteToChar mapping for the given byte slice.

pub fn map(&self, byte_pos: usize) -> usize

Map a byte position to a character position.

pub fn map_span(&self, span: Range<usize>) -> Range<usize>

Map a byte-offset span to a char-offset span.