ParseOptions

Struct ParseOptions 

pub struct ParseOptions { /* private fields */ }
Options used when parsing sql

Implementations

Source

impl ParseOptions

pub fn new() -> Self

pub fn dialect(self, dialect: SQLDialect) -> Self

Change whan SQL dialect to use

pub fn get_dialect(&self) -> SQLDialect

pub fn arguments(self, arguments: SQLArguments) -> Self

Change what kinds of arguments are supplied

pub fn warn_unquoted_identifiers(self, warn_unquoted_identifiers: bool) -> Self

Should we warn about unquoted identifiers

pub fn warn_none_capital_keywords( self, warn_none_capital_keywords: bool, ) -> Self

Should we warn about unquoted identifiers

pub fn list_hack(self, list_hack: bool) -> Self

Parse LIST as special expression

pub fn function_body(self, function_body: bool) -> Self

Parse in function/procedure body mode (allows BEGIN…END blocks)

pub fn get_function_body(&self) -> bool

pub fn span_offset(self, span_offset: usize) -> Self

Set the byte offset of the sub-string being parsed within the outer source file. All spans produced by the lexer will be adjusted by this offset so they remain relative to the outer file.

pub fn get_span_offset(&self) -> usize