pub struct ByteToChar<'a> { /* private fields */ }Expand description
Struct to map byte positions in a UTF-8 string to character positions, for error reporting.
Memory usage is optimized by storing cumulative character counts at 128 byte intervals, which allows for efficient mapping of byte positions to character positions without needing to store a mapping for every single byte.
Implementations
Sourceimpl<'a> ByteToChar<'a>
impl<'a> ByteToChar<'a>